@@ -5,6 +5,6 @@ import langdetect
 class LanguageDetector:
     def detect_what_lang(self, text):
         try:
-            return detect_langs(text)
+            return detect_langs(" ".join(text))
         except langdetect.lang_detect_exception.LangDetectException as e:
             return None
